@@ -54,8 +54,7 @@ from .types import DbtCloudOutput
     tags={"kind": "dbt_cloud"},
 )
 def dbt_cloud_run_op(context):
-    """
-    Initiates a run for a dbt Cloud job, then polls until the run completes. If the job
+    """Initiates a run for a dbt Cloud job, then polls until the run completes. If the job
     fails or is otherwised stopped before succeeding, a `dagster.Failure` exception will be raised,
     and this op will fail.
 
